import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["activeClassName", "activeStyle", "innerRef", "onClick", "onlyActiveOnIndex", "target", "to"];
// from: https://github.com/ReactTraining/react-router/blob/v3/modules/Link.js
import { useCallback } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import invariant from './internal/invariant';
import { useRouter } from './hooks';
/**
 * Check if the event is created with some key being held to know it could be for a some contextual stuff
 * @param {MouseEvent} event Event fired by a mouse on clicking
 * @returns {Boolean} Returns if the event has been modified
 */

import { jsx as _jsx } from "react/jsx-runtime";

var isModifiedEvent = function isModifiedEvent(event) {
  return Boolean(event.metaKey || event.altKey || event.ctrlKey || event.shiftKey);
};
/**
 * Check if the click is the main one, to avoid the contextual ones
 * @param {MouseEvent} event Event fired by a mouse on clicking
 * @returns {Boolean} Returns if the click is the main one. By default, the left click.
 */


var isMainClickEvent = function isMainClickEvent(event) {
  return event.button === 0;
};
/**
 * Check if the target provided is one we want to handle within the router
 * @param {String} target Target provided to an anchor
 * @returns {Boolean} Returns true if the target provided should be handled by the router
 */


var isManageableTarget = function isManageableTarget(target) {
  return !target || target === '_self';
};
/**
 * Resolve location detecting if is a function or string
 * @param {function | string} to
 * @param {import('./types').Router} router
 * @returns {String} Location
 */


var resolveToLocation = function resolveToLocation(to, router) {
  return typeof to === 'function' ? to(router.location) : to;
};

var Link = function Link(_ref) {
  var activeClassName = _ref.activeClassName,
      activeStyle = _ref.activeStyle,
      innerRef = _ref.innerRef,
      onClick = _ref.onClick,
      _ref$onlyActiveOnInde = _ref.onlyActiveOnIndex,
      onlyActiveOnIndex = _ref$onlyActiveOnInde === void 0 ? false : _ref$onlyActiveOnInde,
      target = _ref.target,
      to = _ref.to,
      restOfProps = _objectWithoutPropertiesLoose(_ref, _excluded);

  var router = useRouter();
  var handleClick = useCallback(function (event) {
    if (onClick) onClick(event);

    if (!event.defaultPrevented && // onClick prevented default
    isMainClickEvent(event) && // Ignore everything but left clicks
    isManageableTarget(target) && // Let browser handle "target=_blank" etc.
    !isModifiedEvent(event) // Ignore clicks with modifier keys
    ) {
        event.preventDefault();
        router.push(resolveToLocation(to, router));
      }
  }, [onClick, router, target, to]); // Ignore if rendered outside the context of router

  if (!router) {
    return invariant(router, '<Link>s rendered outside of a router context cannot navigate.');
  } // If user does not specify a `to` prop, return an empty anchor tag
  // but keep some props to be used still


  if (!to) {
    return /*#__PURE__*/_jsx("a", _extends({}, restOfProps, {
      onClick: onClick,
      ref: innerRef
    }));
  } // resolve the location as the `to` prop could be an object


  var toLocation = resolveToLocation(to, router); // check if the route where the Link is pointing is the actual one

  var isActiveRoute = router.isActive(toLocation, onlyActiveOnIndex); // create className and inline styles depending if the route is active
  // if empty string, we default to `undefined` to avoid empty class attribute

  var className = cx(restOfProps.className, isActiveRoute && activeClassName) || undefined;

  var style = _extends({}, restOfProps.style, isActiveRoute && activeStyle);

  var anchorProps = _extends({}, restOfProps, {
    className: className,
    href: router.createHref(toLocation),
    target: target,
    style: style
  });

  return /*#__PURE__*/_jsx("a", _extends({}, anchorProps, {
    onClick: handleClick,
    ref: innerRef
  }));
};

export default Link;